@@ -1,16 +1,16 @@
 # frozen_string_literal: true
 
+require_relative '../catalog'
+
 require 'json'
 
 module OctocatalogDiff
   class Catalog
     # Represents a null Puppet catalog.
-    class Noop
-      attr_accessor :node
-      attr_reader :error_message, :catalog, :catalog_json
-
-      # Constructor
+    class Noop < OctocatalogDiff::Catalog
       def initialize(options)
+        super
+
         @catalog_json = '{"resources":[]}'
         @catalog = { 'resources' => [] }
         @error_message = nil
