@@ -36,6 +36,7 @@ module OctocatalogDiff
         exception_class = nil
         exception_message = nil
         obj_to_return = nil
+        packages = nil
         (retries + 1).times do
           begin
             result = puppetdb.get(uri)
@@ -61,8 +62,48 @@ module OctocatalogDiff
             exception_message = "Fact retrieval failed for node #{node} from PuppetDB (#{exc.message})"
           end
         end
-        return obj_to_return unless obj_to_return.nil?
-        raise exception_class, exception_message
+
+        raise exception_class, exception_message if obj_to_return.nil?
+
+        return obj_to_return if puppetdb_api_version < 4 || (!options[:puppetdb_package_inventory])
+
+        (retries + 1).times do
+          begin
+            result = puppetdb.get("/pdb/query/v4/package-inventory/#{node}")
+            packages = {}
+            result.each do |pkg|
+              key = "#{pkg['package_name']}+#{pkg['provider']}"
+              # Need to handle the situation where a package has multiple versions installed.
+              # The _puppet_inventory_1 hash lists them separated by "; ".
+              if packages.key?(key)
+                packages[key]['version'] += "; #{pkg['version']}"
+              else
+                packages[key] = pkg
+              end
+            end
+            break
+          rescue OctocatalogDiff::Errors::PuppetDBConnectionError => exc
+            exception_class = OctocatalogDiff::Errors::FactSourceError
+            exception_message = "Package inventory retrieval failed (#{exc.class}) (#{exc.message})"
+          # This is not expected to occur, but we'll leave it just in case. A query to package-inventory
+          # for a non-existant node returns a 200 OK with an empty list of packages:
+          rescue OctocatalogDiff::Errors::PuppetDBNodeNotFoundError
+            packages = {}
+          rescue OctocatalogDiff::Errors::PuppetDBGenericError => exc
+            exception_class = OctocatalogDiff::Errors::FactRetrievalError
+            exception_message = "Package inventory retrieval failed for node #{node} from PuppetDB (#{exc.message})"
+          end
+        end
+
+        raise exception_class, exception_message if packages.nil?
+
+        unless packages.empty?
+          obj_to_return['values']['_puppet_inventory_1'] = {
+            'packages' => packages.values.map { |pkg| [pkg['package_name'], pkg['version'], pkg['provider']] }
+          }
+        end
+
+        obj_to_return
       end
     end
   end
